/*(c) Copyright 2015 Pivotal Software, Inc. All Rights Reserved.*/
'use strict';

var _extends = require('babel-runtime/helpers/extends')['default'];

var _objectWithoutProperties = require('babel-runtime/helpers/object-without-properties')['default'];

var classnames = require('classnames');
var React = require('react');
var types = React.PropTypes;

function onClick(value, e) {
  e.preventDefault();
  this.props.onPick(value);
}

var AutocompleteList = React.createClass({
  displayName: 'AutocompleteList',

  propTypes: {
    $autocomplete: types.object,
    children: function children(props, name) {
      if (props[name] && props[name].length) return new Error('AutocompleteList can only wrap one element');
    },
    className: types.string,
    minSearchTerm: types.number,
    onPick: types.func,
    selectedSuggestion: types.any
  },

  getDefaultProps: function getDefaultProps() {
    return { minSearchTerm: 0 };
  },

  renderSuggestionList: function renderSuggestionList() {
    var _this = this;

    var className = this.props.className;

    var suggestedValues = this.props.$autocomplete.get('suggestedValues');
    var suggestions = suggestedValues.map(function (suggestion, key) {
      var className = classnames('autocomplete-item', { highlighted: key === _this.props.$autocomplete.get('highlightedSuggestion') }, { selected: suggestion.value === _this.props.selectedSuggestion });
      return React.createElement(
        'li',
        { key: key },
        React.createElement(
          'a',
          { href: '#', onClick: onClick.bind(_this, suggestion), role: 'button', title: suggestion.value, className: className },
          suggestion.value
        )
      );
    });
    if (!suggestions.length) return null;
    return React.createElement(
      'ul',
      { className: classnames('autocomplete-list', className) },
      suggestions
    );
  },

  renderDefault: function renderDefault() {
    var _props = this.props;
    var $autocomplete = _props.$autocomplete;
    var minSearchTerm = _props.minSearchTerm;

    var _$autocomplete$get = $autocomplete.get();

    var hidden = _$autocomplete$get.hidden;
    var value = _$autocomplete$get.value;

    if (hidden || value.length < minSearchTerm) return null;
    return this.renderSuggestionList();
  },

  render: function render() {
    var _props2 = this.props;
    var children = _props2.children;
    var $autocomplete = _props2.$autocomplete;

    var props = _objectWithoutProperties(_props2, ['children', '$autocomplete']);

    if (!$autocomplete) return null;
    if (!children) return this.renderDefault();

    var _$autocomplete$get2 = $autocomplete.get();

    var hidden = _$autocomplete$get2.hidden;
    var value = _$autocomplete$get2.value;
    var highlightedSuggestion = _$autocomplete$get2.highlightedSuggestion;
    var suggestedValues = _$autocomplete$get2.suggestedValues;

    if (hidden) return null;
    return React.createElement(
      'div',
      null,
      React.Children.map(children, function (e) {
        return React.cloneElement(e, _extends({ value: value, suggestedValues: suggestedValues, highlightedSuggestion: highlightedSuggestion, onClick: onClick }, props));
      })
    );
  }
});

module.exports = AutocompleteList;